## `testpypisszczygielski` - My simple Project

* opt 1
* opt 2
* opt 3

## Install

###`pip install testpypisszczygielski`

### Usage
from m_mod_sszczygielski.py import name\
from m_mod_sszczygielski.py import get_numpy_arr\
print(name("sebastian",  "szczygielski"))\
print(get_numpy_arr([1, 2, 3, 4, 5]))\

###Author 
*SEBA*

